JlsServerConfig

Struct JlsServerConfig 

pub struct JlsServerConfig {
    pub enable: bool,
    pub users: Vec<JlsUser>,
    pub upstream_addr: Option<String>,
    pub upstream_sni: Option<String>,
    pub rate_limit: u64,
}
Jls Server Configuration

Fields

enable: bool

enable JLS or a fall back to normal TLS

users: Vec<JlsUser>

Jls password and iv

upstream_addr: Option<String>

upstream address, for example, example.com:443 If empty, forwarding will be disabled

upstream_sni: Option<String>

server name for upstream, if empty, server name check will be skipped

rate_limit: u64

Limit the rate of JLS forwarding This is not done in rustls but in quinn or tokio-rustls

Implementations

Source

impl JlsServerConfig

pub fn new( pwd: String, iv: String, upstream_addr: Option<String>, upstream_sni: Option<String>, ) -> Self

Create a new jls server configuration

pub fn add_user(self, pwd: String, iv: String) -> Self

Adding JLS config for a new user

pub fn with_upstream_addr(self, addr: String) -> Self

setting upstream address and get default server name if viable

pub fn with_server_name(self, server_name: String) -> Self

setting server name authentication check

pub fn with_rate_limit(self, rate_limit: u64) -> Self

setting rate limit for JLS forwarding

pub fn enable(self, enable: bool) -> Self

Enable JLS